[pve-devel] [PATCH manager 1/2] vzdump-hook-script: rename TARFILE to TARGET

Stoiko Ivanov s.ivanov at proxmox.com
Tue Jul 14 10:09:18 CEST 2020


with the change introduced in 848cf539e59b4553559b9ff3207a3c5556dc1cc0 the
exported variable name changed from tarfile to target.

this patch reflects the renaming in the example hook script.

Signed-off-by: Stoiko Ivanov <s.ivanov at proxmox.com>
---
 vzdump-hook-script.pl | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/vzdump-hook-script.pl b/vzdump-hook-script.pl
index 4be46211..1be440b3 100755
--- a/vzdump-hook-script.pl
+++ b/vzdump-hook-script.pl
@@ -43,17 +43,17 @@ if ($phase eq 'job-start' ||
 
     my $hostname = $ENV{HOSTNAME};
 
-    # tarfile is only available in phase 'backup-end'
-    my $tarfile = $ENV{TARFILE};
+    # target is only available in phase 'backup-end'
+    my $target = $ENV{TARGET};
 
     # logfile is only available in phase 'log-end'
     my $logfile = $ENV{LOGFILE};
 
-    print "HOOK-ENV: vmtype=$vmtype;dumpdir=$dumpdir;storeid=$storeid;hostname=$hostname;tarfile=$tarfile;logfile=$logfile\n";
+    print "HOOK-ENV: vmtype=$vmtype;dumpdir=$dumpdir;storeid=$storeid;hostname=$hostname;target=$target;logfile=$logfile\n";
 
     # example: copy resulting backup file to another host using scp
     if ($phase eq 'backup-end') {
-        #system ("scp $tarfile backup-host:/backup-dir") == 0 ||
+        #system ("scp $target backup-host:/backup-dir") == 0 ||
         #    die "copy tar file to backup-host failed";
     }
 
-- 
2.20.1






More information about the pve-devel mailing list